import React from 'react';
import './Launchpad.css';
import { LaunchpadButton, LaunchpadButtonProps, EditPadButton } from '../LaunchpadButton/types';

export interface Selectable {
    onSelected?: (key: string) => void;
}

export type Flow = "horizontal" | "vertical";

interface LaunchpadProps {
    title?: string;
    exclusive: boolean;
    flow?: Flow;
    options: Array<LaunchpadButtonProps>;
}

const exclusiveSelect = (state: { [key: string]: boolean }, targetId: string) => {
    console.log("running exclusiveSelect on ", targetId);
    return { [targetId]: true };
}

const multiSelect = (state: { [key: string]: boolean }, targetId: string) => {
    if (state[targetId]) {
        return { ...state, [targetId]: false };
    } else {
        return { ...state, [targetId]: true };
    }
}

const Launchpad = ({ title, flow = "horizontal", options, exclusive }: LaunchpadProps) => {
    const [selected, dispatch] = React.useReducer(exclusive ? exclusiveSelect : multiSelect, {});

    let tiedOptions = options.map(option =>
        <LaunchpadButton key={option.title} title={option.title} onSelected={(key: string) => dispatch(key)} activated={selected[option.title]} />
    );

    return (<div className="launchpad">
        {title && <h1 className="launchpad__title"> {title} </h1>}
        <div className={flow === "horizontal" ? "launchpad_horizontal-flow" : "launchpad_vertical-flow"}>
            {tiedOptions}
            <EditPadButton text="Add" />
        </div>
    </div>)
}

export default Launchpad;
